@@ -437,6 +437,7 @@ class SearchDialog(QDialog, Ui_searchDialog):
     Dialog enabling the user to search YouTube videos.
     """
     searchOrder = 0
+    recentSearches = QStringList()
     def __init__(self, parent = None,  username = None):
         """
         Constructor
@@ -455,7 +456,7 @@ class SearchDialog(QDialog, Ui_searchDialog):
         except:
             pass
         self.searchOrderButton = QMaemo5ValueButton("Order results by:", self)
-        self.searchOrderButton.setValueLayout(QMaemo5ValueButton.ValueBesideText)
+        self.searchOrderButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
         self.searchOrderModel = QStandardItemModel(0, 1)
         for order in ("Date published", "Relevance", "View count", "Rating"):
             item = QStandardItem(order)
@@ -466,22 +467,43 @@ class SearchDialog(QDialog, Ui_searchDialog):
         self.searchOrderSelector.setModel(self.searchOrderModel)
         self.searchOrderButton.setPickSelector(self.searchOrderSelector)
         self.searchOrderSelector.setCurrentIndex(SearchDialog.searchOrder)
+        self.recentSearchesButton = QMaemo5ValueButton("Recent Searches", self)
+        self.recentSearchesButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
+        self.recentSearchesModel = QStandardItemModel(0, 1)
+        for searchString in SearchDialog.recentSearches:
+            item = QStandardItem(searchString)
+            item.setEditable(False)
+            item.setTextAlignment(Qt.AlignCenter)
+            self.recentSearchesModel.appendRow(item)
+        self.recentSearchesSelector = QMaemo5ListPickSelector()
+        self.recentSearchesSelector.setModel(self.recentSearchesModel)
+        self.recentSearchesButton.setPickSelector(self.recentSearchesSelector)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+        self.connect(self.recentSearchesSelector,  SIGNAL("selected(QString)"), self.selectRecentSearch)
         self.orientationChanged()
         self.show()
       
     def orientationChanged(self):
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
-            self.resize(480, 270)
+            self.resize(480, 330)
             self.lineEdit.setGeometry(QRect(10, 10, 460, 70))
             self.searchOrderButton.setGeometry(QRect(10, 90, 460, 70))
-            self.searchButton.setGeometry(QRect(10, 180, 460, 70))      
+            self.recentSearchesButton.setGeometry(QRect(10, 170, 460, 70))
+            self.searchButton.setGeometry(QRect(10, 250, 460, 70))      
         else:
-            self.resize(800, 170)
+            self.resize(800, 250)
             self.lineEdit.setGeometry(QRect(10, 10, 600, 70))
             self.searchOrderButton.setGeometry(QRect(10, 90, 600, 70))
-            self.searchButton.setGeometry(QRect(640, 90, 150, 70))                  
+            self.recentSearchesButton.setGeometry(QRect(10, 170, 600, 70))
+            self.searchButton.setGeometry(QRect(640, 170, 150, 70))  
+
+    def selectRecentSearch(self,  searchString):
+        """
+        Sets the text of the lineEdit to the selected search string.
+        """
+        self.lineEdit.setText(searchString)
+        self.recentSearchesButton.setValueText("")
 
     @pyqtSignature("")    
     def on_searchButton_clicked(self):
@@ -492,7 +514,12 @@ class SearchDialog(QDialog, Ui_searchDialog):
         searchString = unicode(self.lineEdit.text())
         searchDict = {"Date published": "published", "Relevance": "relevance", "View count": "viewCount", "Rating": "rating"}
         searchOrder = searchDict.get(unicode(self.searchOrderButton.valueText()))
+        if searchString in SearchDialog.recentSearches:
+            SearchDialog.recentSearches.removeAll(searchString)
+        SearchDialog.recentSearches.prepend(searchString)
         searchWindow = cutetubewindows.SearchResultsWindow(self, searchString, searchOrder, self.username)
+        
+    
 
 class SettingsDialog(QDialog):
     """
