@@ -442,7 +442,7 @@ class MostViewedWindow(CutetubeWindows):
         Constructor
         """
         CutetubeWindows.__init__(self, parent)
-        self.setWindowTitle("Most Popular")
+        self.setWindowTitle("Today's Most Viewed")
         self.actionAddToQueue.setVisible(True)
         self.actionAddToFavourites.setVisible(True)
         self.actionAddToPlaylist.setVisible(True)
@@ -450,7 +450,7 @@ class MostViewedWindow(CutetubeWindows):
         self.pencilList = []
         self.results = 0
         self.show()
-        self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_popular"
+        self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_viewed?time=today"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
@@ -475,6 +475,7 @@ class SearchResultsWindow(CutetubeWindows):
         self.searchString = searchString
         self.pencilList = []
         self.results = 0
+        self.info = False
         self.show() 
         searchTerms = self.searchString.replace(" ", "+")
         if username == None:
@@ -484,19 +485,38 @@ class SearchResultsWindow(CutetubeWindows):
             self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=%s&vq=%s&orderby=%s" (username, searchTerms, searchOrder)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusyandCheckResults)        
         self.loadData()
         self.toggleBusy(True)
 
-    def loadData(self):
-        try:
-            self.yt.start()
-            QMaemo5InformationBox.information(self, "Showing results for \'%s\'" % self.searchString)
-        except:
-            try:
-                QMaemo5InformationBox.information(self, "Unable to connect to YouTube, please try again")
-            except:
-                pass
+    def addVideo(self, videoData):
+        """
+        Overrides the method in CutetubeWindows to inform 
+        the user of search results.
+        """
+        size = QSize()
+        size.setHeight(79)
+        item = QListWidgetItem()
+        item.setSizeHint(size)
+        itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
+        self.listWidget.addItem(item)
+        self.listWidget.setItemWidget(item, itemWidget)
+        title = itemWidget.titleLabel.text()
+        author = itemWidget.authorLabel.text()
+        self.results += 1
+        if not self.info:
+            QMaemo5InformationBox.information(self,  "Showing results for \'%s\'" % self.searchString)
+            self.info = True
+                
+    def toggleBusyandCheckResults(self, isBusy):
+        """
+        Hides the progress indicator and informs the user if there are no results.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
+        if not self.info:
+            if self.results == 0:
+                QMaemo5InformationBox.information(self,  "No results found for \'%s\'" % self.searchString)
+            self.info == True
 
 class UploadsWindow(CutetubeWindows):
     """
