@@ -39,13 +39,17 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         self.youtubeLabel.setScaledContents(True)
         self.orientationChanged()
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+        self.keyPressEvent = self.showSearchDialog
+        for button in (self.myAccountButton, self.mostRecentButton, self.mostViewedButton, self.searchButton):
+            button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px;") 
         taskQueueLength = len(youtubeservice.YouTubeVideoDownloader.taskQueue)
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
             self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
         self.show()
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
         self.restoreSettings()
-        QTimer.singleShot(2000,  self.youtubeLogin)
+        QTimer.singleShot(3000,  self.youtubeLogin)
         
     def youtubeLogin(self):
         """
@@ -66,6 +70,17 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
                 QMaemo5InformationBox.information(self, "You are signed in to YouTube as \'%s\'" % username)
             except:
                 QMaemo5InformationBox.information(self, "Unable to sign in to your YouTube account")
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+                
+    def showSearchDialog(self,  event):
+        """
+        Raises a SearchDialog when the user presses a key.
+        """
+        if event.key() not in (Qt.Key_Left, Qt.Key_Right, Qt.Key_Up, Qt.Key_Down, Qt.Key_Backspace, Qt.Key_Return, Qt.Key_Control, Qt.Key_Shift, Qt.Key_Space):
+            searchDialog = cutetubedialogs.SearchDialog(self)
+            searchDialog.lineEdit.insert(event.text())
+        else:
+            pass
                 
     def restoreSettings(self):
         """
@@ -83,6 +98,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
             youtubeservice.YouTubeVideoPlayer.playbackFormat = settings.value("playbackFormat",  "18").toPyObject()
         youtubeservice.YouTubeVideoDownloader.downloadFormat = settings.value("downloadFormat",  "18").toPyObject()
         cutetubedialogs.SearchDialog.searchOrder = settings.value("searchOrder",  0).toInt()[0]
+        cutetubedialogs.SearchDialog.recentSearches = settings.value("recentSearches", QStringList()).toStringList()
         
     def closeEvent(self,  event):
         """
@@ -98,6 +114,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         playbackFormat = QVariant(youtubeservice.YouTubeVideoPlayer.playbackFormat)
         downloadFormat = QVariant(youtubeservice.YouTubeVideoDownloader.downloadFormat)
         searchOrder = QVariant(cutetubedialogs.SearchDialog.searchOrder)
+        recentSearches = QVariant(cutetubedialogs.SearchDialog.recentSearches)
         settings.setValue("userDict", userDict)
         settings.setValue("defaultUser", defaultUser)
         settings.setValue("noAccountDialog", noAccountDialog)
@@ -107,6 +124,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         settings.setValue("playbackFormat", playbackFormat)
         settings.setValue("downloadFormat", downloadFormat)
         settings.setValue("searchOrder", searchOrder)
+        settings.setValue("recentSearches", recentSearches)
 
     def orientationChanged(self):
         """
@@ -119,9 +137,9 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
             self.mostRecentButton.setGeometry(QRect(280, 150, 120, 120))
             self.mostViewedButton.setGeometry(QRect(80, 400, 120, 120))
             self.searchButton.setGeometry(QRect(280, 400, 120, 120))
-            self.myAccountLabel.setGeometry(QRect(77, 278, 127, 26))
-            self.mostRecentLabel.setGeometry(QRect(278, 278, 132, 26))
-            self.mostViewedLabel.setGeometry(QRect(75, 527, 135, 26))
+            self.myAccountLabel.setGeometry(QRect(76, 278, 127, 26))
+            self.mostRecentLabel.setGeometry(QRect(274, 278, 132, 26))
+            self.mostViewedLabel.setGeometry(QRect(72, 527, 135, 26))
             self.searchLabel.setGeometry(QRect(301, 527, 75, 26))
         else:
             self.resize(800, 480)
@@ -129,10 +147,10 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
             self.mostRecentButton.setGeometry(QRect(243, 123, 120, 120))
             self.mostViewedButton.setGeometry(QRect(434, 123, 120, 120))
             self.searchButton.setGeometry(QRect(628, 123, 120, 120))
-            self.myAccountLabel.setGeometry(QRect(54, 250, 127, 26))
-            self.mostRecentLabel.setGeometry(QRect(241, 250, 132, 26))
-            self.mostViewedLabel.setGeometry(QRect(429, 250, 135, 26))
-            self.searchLabel.setGeometry(QRect(649, 250, 75, 26))
+            self.myAccountLabel.setGeometry(QRect(53, 250, 127, 26))
+            self.mostRecentLabel.setGeometry(QRect(239, 250, 132, 26))
+            self.mostViewedLabel.setGeometry(QRect(426, 250, 135, 26))
+            self.searchLabel.setGeometry(QRect(651, 250, 75, 26))
 
     def queueChanged(self, queueLength):
         """
