@@ -50,8 +50,15 @@ class YouTubeDataService(object):
         """       
         YouTubeDataService.ytService.email = unicode(YouTubeDataService.userDict[username][0], "utf-8")
         YouTubeDataService.ytService.password = unicode(YouTubeDataService.userDict[username][1], "utf-8")
-        YouTubeDataService.ytService.ProgrammaticLogin()
-        YouTubeDataService.currentUser = username
+        try:
+            YouTubeDataService.ytService.ProgrammaticLogin()
+            YouTubeDataService.currentUser = username
+        except:
+            # Some users have reported authentication issues. Using the username in place of the email address may work.
+            YouTubeDataService.ytService.email = unicode(username, "utf-8")
+            YouTubeDataService.ytService.password = unicode(YouTubeDataService.userDict[username][1], "utf-8")
+            YouTubeDataService.ytService.ProgrammaticLogin()
+            YouTubeDataService.currentUser = username
         
     @staticmethod
     def addComment(comment, videoID):
